==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/core/src/test/java/org/apache/servicecomb/core/handler/impl/TestServiceProviderHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.core.handler.impl;

import org.apache.servicecomb.core.Invocation;
import org.apache.servicecomb.core.definition.OperationMeta;
import org.apache.servicecomb.swagger.invocation.AsyncResponse;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mockito;

public class TestServiceProviderHandler {

  ProducerOperationHandler serviceProviderHandler = null;

  Invocation invocation = null;

  AsyncResponse asyncResp = null;

  OperationMeta OperationMeta = null;

  @Before
  public void setUp() throws Exception {
    serviceProviderHandler = new ProducerOperationHandler();
    invocation = Mockito.mock(Invocation.class);
    asyncResp = Mockito.mock(AsyncResponse.class);
    OperationMeta = Mockito.mock(OperationMeta.class);
  }

  @After
  public void tearDown() throws Exception {
    serviceProviderHandler = null;
    invocation = null;
    asyncResp = null;
    OperationMeta = null;
  }

  @Test
  public void testHandle() {
    boolean status = false;
    try {
      Assert.assertNotNull(serviceProviderHandler);
      Mockito.when(invocation.getOperationMeta()).thenReturn(OperationMeta);
      serviceProviderHandler.handle(invocation, asyncResp);
    } catch (Exception e) {
      status = true;
    }
    Assert.assertFalse(status);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.16-src.zip: apache-servicecomb-java-chassis-distribution-2.8.16-src/core/src/test/java/org/apache/servicecomb/core/handler/impl/TestServiceProviderHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.core.handler.impl;

import org.apache.servicecomb.core.Invocation;
import org.apache.servicecomb.core.definition.OperationMeta;
import org.apache.servicecomb.swagger.invocation.AsyncResponse;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.jupiter.api.Assertions;
import org.mockito.Mockito;

public class TestServiceProviderHandler {

  ProducerOperationHandler serviceProviderHandler = null;

  Invocation invocation = null;

  AsyncResponse asyncResp = null;

  OperationMeta OperationMeta = null;

  @Before
  public void setUp() throws Exception {
    serviceProviderHandler = new ProducerOperationHandler();
    invocation = Mockito.mock(Invocation.class);
    asyncResp = Mockito.mock(AsyncResponse.class);
    OperationMeta = Mockito.mock(OperationMeta.class);
  }

  @After
  public void tearDown() {
    serviceProviderHandler = null;
    invocation = null;
    asyncResp = null;
    OperationMeta = null;
  }

  @Test
  public void testHandle() {
    boolean status = false;
    try {
      Assertions.assertNotNull(serviceProviderHandler);
      Mockito.when(invocation.getOperationMeta()).thenReturn(OperationMeta);
      serviceProviderHandler.handle(invocation, asyncResp);
    } catch (Exception e) {
      e.printStackTrace();
      status = true;
    }
    Assertions.assertFalse(status);
  }
}
